Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(421)

Unified Diff: third_party/WebKit/Source/core/input/PointerEventManager.h

Issue 2646163002: Remove PlatformTouchEvent/Point and use WebTouchEvent/Point instead (Closed)
Patch Set: Fix nit Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/input/PointerEventManager.h
diff --git a/third_party/WebKit/Source/core/input/PointerEventManager.h b/third_party/WebKit/Source/core/input/PointerEventManager.h
index f3163348e2f40745cfb973c48e452b38f9b13f4e..8504f5c47b478e9b0580b4300d3b382f1902f9f4 100644
--- a/third_party/WebKit/Source/core/input/PointerEventManager.h
+++ b/third_party/WebKit/Source/core/input/PointerEventManager.h
@@ -41,8 +41,8 @@ class CORE_EXPORT PointerEventManager
const Vector<PlatformMouseEvent>& coalescedEvents);
WebInputEventResult handleTouchEvents(
- const PlatformTouchEvent&,
- const Vector<PlatformTouchEvent>& coalescedEvents);
+ const WebTouchEvent&,
+ const Vector<WebTouchEvent>& coalescedEvents);
// Sends boundary events pointerout/leave/over/enter and
// mouseout/leave/over/enter to the corresponding targets.
@@ -136,16 +136,15 @@ class CORE_EXPORT PointerEventManager
// blockTouchPointers().
void unblockTouchPointers();
- // Generate the TouchInfos for a PlatformTouchEvent, hit-testing as necessary.
- void computeTouchTargets(const PlatformTouchEvent&,
+ // Generate the TouchInfos for a WebTouchEvent, hit-testing as necessary.
+ void computeTouchTargets(const WebTouchEvent&,
HeapVector<TouchEventManager::TouchInfo>&);
// Sends touch pointer events and sets consumed bits in TouchInfo array
// based on the return value of pointer event handlers.
- void dispatchTouchPointerEvents(
- const PlatformTouchEvent&,
- const Vector<PlatformTouchEvent>& coalescedEvents,
- HeapVector<TouchEventManager::TouchInfo>&);
+ void dispatchTouchPointerEvents(const WebTouchEvent&,
+ const Vector<WebTouchEvent>& coalescedEvents,
+ HeapVector<TouchEventManager::TouchInfo>&);
// Returns whether the event is consumed or not.
WebInputEventResult sendTouchPointerEvent(EventTarget*, PointerEvent*);
« no previous file with comments | « third_party/WebKit/Source/core/input/EventHandler.cpp ('k') | third_party/WebKit/Source/core/input/PointerEventManager.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698